nxp-pac

Crates

git

Versions

lpc55s16

Flavors

MiscCfg

Struct MiscCfg 

#[repr(transparent)]
pub struct MiscCfg(pub u32);
no description available

Tuple Fields

0: u32

Implementations

Source

impl MiscCfg

pub const fn aes_reseed(&self) -> bool

If set, ENCRYPTED_NUMBER generation becomes predictable, provided all secrets and current internal state are known: independant from entropy source.

pub const fn set_aes_reseed(&mut self, val: bool)

If set, ENCRYPTED_NUMBER generation becomes predictable, provided all secrets and current internal state are known: independant from entropy source.

pub const fn aes_dt_cfg(&self) -> bool

Set this bit to re-seed AES.

pub const fn set_aes_dt_cfg(&mut self, val: bool)

Set this bit to re-seed AES.