nxp-pac

Crates

git

Versions

lpc55s16

Flavors

Powerdown

Struct Powerdown 

#[repr(transparent)]
pub struct Powerdown(pub u32);
Powerdown mode (standard but certainly useless here)

Tuple Fields

0: u32

Implementations

Source

impl Powerdown

pub const fn soft_reset(&self) -> bool

Request softreset that will go low automaticaly after acknowledge from CORE.

pub const fn set_soft_reset(&mut self, val: bool)

Request softreset that will go low automaticaly after acknowledge from CORE.

pub const fn force_soft_reset(&self) -> bool

When used with softreset it forces CORE_RESETN to low on acknowledge from CORE.

pub const fn set_force_soft_reset(&mut self, val: bool)

When used with softreset it forces CORE_RESETN to low on acknowledge from CORE.

pub const fn powerdown(&self) -> bool

When set all accesses to standard registers are blocked.

pub const fn set_powerdown(&mut self, val: bool)

When set all accesses to standard registers are blocked.