#[repr(transparent)]pub struct MiscCfg(pub u32);Expand description
no description available
Tuple Fields
0: u32Implementations
Sourceimpl MiscCfg
impl MiscCfg
Sourcepub const fn aes_reseed(&self) -> bool
pub const fn aes_reseed(&self) -> bool
If set, ENCRYPTED_NUMBER generation becomes predictable, provided all secrets and current internal state are known: independant from entropy source.
Sourcepub const fn set_aes_reseed(&mut self, val: bool)
pub const fn set_aes_reseed(&mut self, val: bool)
If set, ENCRYPTED_NUMBER generation becomes predictable, provided all secrets and current internal state are known: independant from entropy source.
Sourcepub const fn aes_dt_cfg(&self) -> bool
pub const fn aes_dt_cfg(&self) -> bool
Set this bit to re-seed AES.
Sourcepub const fn set_aes_dt_cfg(&mut self, val: bool)
pub const fn set_aes_dt_cfg(&mut self, val: bool)
Set this bit to re-seed AES.