#[repr(transparent)]pub struct Powerdown(pub u32);Expand description
Powerdown mode (standard but certainly useless here)
Tuple Fields
0: u32Implementations
Sourceimpl Powerdown
impl Powerdown
Sourcepub const fn soft_reset(&self) -> bool
pub const fn soft_reset(&self) -> bool
Request softreset that will go low automaticaly after acknowledge from CORE.
Sourcepub const fn set_soft_reset(&mut self, val: bool)
pub const fn set_soft_reset(&mut self, val: bool)
Request softreset that will go low automaticaly after acknowledge from CORE.
Sourcepub const fn force_soft_reset(&self) -> bool
pub const fn force_soft_reset(&self) -> bool
When used with softreset it forces CORE_RESETN to low on acknowledge from CORE.
Sourcepub const fn set_force_soft_reset(&mut self, val: bool)
pub const fn set_force_soft_reset(&mut self, val: bool)
When used with softreset it forces CORE_RESETN to low on acknowledge from CORE.
Sourcepub const fn set_powerdown(&mut self, val: bool)
pub const fn set_powerdown(&mut self, val: bool)
When set all accesses to standard registers are blocked.